#!/usr/bin/env python
# unity-webapps-telegram
# Copyright (C) 2014 Marcos Alvarez Costales https://launchpad.net/~costales
#
# unity-webapps-telegram is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# unity-webapps-telegram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with unity-webapps-telegram; if not, see http://www.gnu.org/licenses
# for more information.


import os, sys, glob, sqlite3, commands, webbrowser
from gi.repository import Gtk, Gdk


class Preferences:
    def __init__(self):
        # Read current config
        self.f_cfg = self._get_file_cfg()
        if not self.f_cfg:
            print("Error: Not Local Storage file for Telegram webapp")
            sys.exit()
        
        self._read_cfg()
        
        # Load GUI
        self.builder = Gtk.Builder()
        self.builder.add_from_file('/usr/share/telegram/ui/preferences.ui')
        self._set_GUI_values()
        self.builder.connect_signals(self)
        
        Gtk.main()
    
    def _get_file_cfg(self):
        f_cfg = os.path.join(os.getenv("HOME"), '.local', 'share', 'Telegramzhukovgithubio', 'Local Storage')
        f_files = glob.glob(os.path.join(f_cfg, '*.localstorage'))
        if (len(f_files) == 1):
            return os.path.join(f_cfg, f_files[0])
        return ""
    
    def _set_GUI_values(self):
        self.lbl_warning = self.builder.get_object('warning')
        
        self.donate_box  = self.builder.get_object('donate_box')
        if not self._get_ddbb_value('show_donate', True):
            self.donate_box.set_visible(False)

        self.cb_autostart     = self.builder.get_object('autostart')
        self.cb_count         = self.builder.get_object('count')
        self.cb_messagingmenu = self.builder.get_object('messagingmenu')
        self.cb_notifications = self.builder.get_object('notifications')
        self.cb_urgent        = self.builder.get_object('urgent')
        
        self.cb_autostart.set_active(self.sw_autostart)
        self.cb_count.set_active(self.sw_count)
        self.cb_messagingmenu.set_active(self.sw_messagingmenu)
        self.cb_notifications.set_active(self.sw_notifications)
        self.cb_urgent.set_active(self.sw_urgent)
    
    def _read_cfg(self):
        self.sw_autostart = os.path.isfile(os.path.join(os.getenv("HOME"), ".config", "autostart", "Telegramzhukovgithubio.desktop"))
        self.sw_count         = self._get_ddbb_value('count', True)
        self.sw_messagingmenu = self._get_ddbb_value('messagingmenu', True)
        self.sw_notifications = self._get_ddbb_value('notifications')
        self.sw_urgent        = self._get_ddbb_value('urgent')
        
    def _get_ddbb_value(self, key, by_default=False):
        conn = sqlite3.connect(self.f_cfg)
        c = conn.cursor()
        c.execute("SELECT key,value FROM ItemTable where key='" + key + "'")
        conn.commit()
        try:
            if c.fetchone()[1] == '1':
                value = True
            else:
                value = False
        except:
            value = by_default
        conn.close()
        return value
    
    def _set_ddbb_value(self, key, value):
        conn = sqlite3.connect(self.f_cfg)
        c = conn.cursor()
        if value:
            c.execute("INSERT OR IGNORE INTO ItemTable (key,value) VALUES('" + key + "', '1')")
            c.execute("UPDATE ItemTable SET value='1' where key='" + key + "'")
        else:
            c.execute("INSERT OR IGNORE INTO ItemTable (key,value) VALUES('" + key + "', '0')")
            c.execute("UPDATE ItemTable SET value='0' where key='" + key + "'")
        conn.commit()
        conn.close()
    
    def on_preferences_delete_event(self, widget, data=None):
        Gtk.main_quit()
    
    def on_close_win_clicked(self, widget, data=None):
        Gtk.main_quit()
    
    def on_donate_clicked(self, widget, data=None):
        webbrowser.open_new("http://gufw.org/donate_telegram")
    
    def on_hide_donate_clicked(self, widget, data=None):
        self.donate_box.set_visible(False)
        self._set_ddbb_value('show_donate', False)
    
    def on_autostart_toggled(self, widget, data=None):
        self._set_ddbb_value('autostart', self.cb_autostart.get_active())
        if self.cb_autostart.get_active():
            commands.getstatusoutput("LANGUAGE=C mkdir " + os.path.join(os.getenv("HOME"), ".config", "autostart"))
            commands.getstatusoutput("LANGUAGE=C cp /usr/share/applications/Telegramzhukovgithubio.desktop " + os.path.join(os.getenv("HOME"), ".config", "autostart"))
        else:
            commands.getstatusoutput("LANGUAGE=C rm " + os.path.join(os.getenv("HOME"), ".config", "autostart", "Telegramzhukovgithubio.desktop"))
    
    def on_count_toggled(self, widget, data=None):
        self.lbl_warning.set_visible(True)
        self._set_ddbb_value('count', self.cb_count.get_active())
    
    def on_messagingmenu_toggled(self, widget, data=None):
        self.lbl_warning.set_visible(True)
        self._set_ddbb_value('messagingmenu', self.cb_messagingmenu.get_active())
    
    def on_notifications_toggled(self, widget, data=None):
        self.lbl_warning.set_visible(True)
        self._set_ddbb_value('notifications', self.cb_notifications.get_active())
    
    def on_urgent_toggled(self, widget, data=None):
        self.lbl_warning.set_visible(True)
        self._set_ddbb_value('urgent', self.cb_urgent.get_active())
    
    
if __name__ == '__main__':
    app = Preferences()
